@@ -26,10 +26,10 @@ java {
 dependencies {
 	compileOnly("org.apache.ant:ant:1.10.12")
 	testImplementation("org.assertj:assertj-core:3.23.1")
-	testImplementation("org.junit.jupiter:junit-jupiter:5.9.0")
+	testImplementation("org.junit.jupiter:junit-jupiter:5.9.1")
 	testImplementation("org.scilab.forge:jlatexmath:1.0.7")
 	"pdfRuntimeOnly"("org.apache.xmlgraphics:fop:2.7")
-	"pdfRuntimeOnly"("org.apache.xmlgraphics:batik-all:1.14")
+	"pdfRuntimeOnly"("org.apache.xmlgraphics:batik-all:1.15")
 }
 
 repositories {
@@ -112,16 +112,14 @@ publishing {
 		suppressAllPomMetadataWarnings()
 	}
 	repositories {
-		maven {
-			name = "fstest"
-			url = uri(layout.buildDirectory.dir("repo"))
-		}
 		maven {
 			name = "OSSRH"
-			url = uri("https://oss.sonatype.org/service/local/staging/deploy/maven2/")
+			val releasesRepoUrl = "https://oss.sonatype.org/service/local/staging/deploy/maven2/"
+			val snapshotsRepoUrl = "https://oss.sonatype.org/content/repositories/snapshots/"
+			url = uri(if (version.toString().endsWith("SNAPSHOT")) snapshotsRepoUrl else releasesRepoUrl)
 			credentials {
-				username = System.getenv("MAVEN_USERNAME")
-				password = System.getenv("MAVEN_PASSWORD")
+				username = System.getenv("OSSRH_USERNAME")
+				password = System.getenv("OSSRH_PASSWORD")
 			}
 		}
 	}
