@@ -50,6 +50,7 @@ import javax.crypto.SecretKeyFactory;
 import javax.crypto.spec.PBEKeySpec;
 
 import net.sourceforge.plantuml.code.AsciiEncoder;
+import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.security.SFile;
 
 public class SignatureUtils {
@@ -77,10 +78,10 @@ public class SignatureUtils {
 			final byte[] digest = getMD5raw(s);
 			return toString(digest);
 		} catch (NoSuchAlgorithmException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		} catch (UnsupportedEncodingException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		}
 	}
@@ -104,10 +105,10 @@ public class SignatureUtils {
 			assert digest.length == 16;
 			return toHexString(digest);
 		} catch (NoSuchAlgorithmException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		} catch (UnsupportedEncodingException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		}
 	}
@@ -118,10 +119,10 @@ public class SignatureUtils {
 			assert digest.length == 64;
 			return toHexString(digest);
 		} catch (NoSuchAlgorithmException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		} catch (UnsupportedEncodingException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		}
 	}
@@ -160,10 +161,10 @@ public class SignatureUtils {
 			final byte[] digest = msgDigest.digest();
 			return toString(digest);
 		} catch (NoSuchAlgorithmException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		} catch (UnsupportedEncodingException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		}
 	}
@@ -194,10 +195,10 @@ public class SignatureUtils {
 			final byte[] digest = msgDigest.digest();
 			return toString(digest);
 		} catch (NoSuchAlgorithmException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		} catch (UnsupportedEncodingException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new UnsupportedOperationException(e);
 		}
 	}
