@@ -35,9 +35,7 @@
  */
 package net.sourceforge.plantuml;
 
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.sprite.Sprite;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 
 public interface SpriteContainer extends SvgCharSizeHack {
 
@@ -45,8 +43,4 @@ public interface SpriteContainer extends SvgCharSizeHack {
 
 	public Guillemet guillemet();
 
-	public ThemeStyle getThemeStyle();
-
-	public ColorMapper getColorMapper();
-
 }
\ No newline at end of file
