@@ -35,15 +35,13 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.gtile;
 
-import java.awt.geom.Point2D;
-
-import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.Direction;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Arrows;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Hexagon;
 import net.sourceforge.plantuml.activitydiagram3.ftile.MergeStrategy;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Snake;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -72,8 +70,8 @@ public class GConnectionHorizontalThenVerticalDown extends GAbstractConnection {
 	public void drawTranslate(UGraphic ug, UTranslate translate1, UTranslate translate2) {
 //		final Snake snake = Snake.create(getInLinkRenderingColor(), Arrows.asToDown()).withLabel(textBlock,
 //				HorizontalAlignment.LEFT);
-		Point2D p1 = pos1.getTranslated(gpoint1.getPoint2D());
-		Point2D p2 = pos2.getTranslated(gpoint2.getPoint2D());
+		XPoint2D p1 = pos1.getTranslated(gpoint1.getPoint2D());
+		XPoint2D p2 = pos2.getTranslated(gpoint2.getPoint2D());
 
 		final Direction originalDirection = Direction.leftOrRight(p1, p2);
 		p1 = translate1.getTranslated(p1);
@@ -83,7 +81,7 @@ public class GConnectionHorizontalThenVerticalDown extends GAbstractConnection {
 			final double delta = (originalDirection == Direction.RIGHT ? -1 : 1) * Hexagon.hexagonHalfSize;
 			// final Dimension2D dimDiamond1 =
 			// diamond1.calculateDimension(ug.getStringBounder());
-			final Dimension2D dimDiamond1 = new Dimension2DDouble(0, 0);
+			final XDimension2D dimDiamond1 = new XDimension2D(0, 0);
 			final Snake small = Snake.create(skinParam(), getInLinkRenderingColor()).withLabel(textBlock, HorizontalAlignment.LEFT);
 			small.addPoint(p1);
 			small.addPoint(p1.getX() + delta, p1.getY());
@@ -106,10 +104,10 @@ public class GConnectionHorizontalThenVerticalDown extends GAbstractConnection {
 	public void drawU(UGraphic ug) {
 		final Snake snake = Snake.create(skinParam(), getInLinkRenderingColor(), Arrows.asToDown()).withLabel(textBlock,
 				HorizontalAlignment.LEFT);
-		final Point2D p1 = pos1.getTranslated(gpoint1.getPoint2D());
-		final Point2D p2 = pos2.getTranslated(gpoint2.getPoint2D());
+		final XPoint2D p1 = pos1.getTranslated(gpoint1.getPoint2D());
+		final XPoint2D p2 = pos2.getTranslated(gpoint2.getPoint2D());
 		snake.addPoint(p1);
-		snake.addPoint(new Point2D.Double(p2.getX(), p1.getY()));
+		snake.addPoint(new XPoint2D(p2.getX(), p1.getY()));
 		snake.addPoint(p2);
 		ug.draw(snake);
 	}
@@ -154,8 +152,8 @@ public class GConnectionHorizontalThenVerticalDown extends GAbstractConnection {
 //	@Override
 //	public void drawTranslate(UGraphic ug, UTranslate translate1, UTranslate translate2) {
 //		final Snake snake = Snake.create(color, Arrows.asToDown()).withLabel(textBlock, HorizontalAlignment.LEFT);
-//		final Point2D mp1a = translate1.getTranslated(p1);
-//		final Point2D mp2b = translate2.getTranslated(p2);
+//		final XPoint2D mp1a = translate1.getTranslated(p1);
+//		final XPoint2D mp2b = translate2.getTranslated(p2);
 //		final double middle = (mp1a.getY() + mp2b.getY()) / 2.0;
 //		snake.addPoint(mp1a);
 //		snake.addPoint(mp1a.getX(), middle);
