@@ -35,6 +35,7 @@ import java.util.prefs.Preferences;
 
 import net.sourceforge.plantuml.Log;
 import net.sourceforge.plantuml.annotation.HaxeIgnored;
+import net.sourceforge.plantuml.log.Logme;
 @HaxeIgnored
 public class NumberAnalyzed implements INumberAnalyzed {
 
@@ -121,7 +122,7 @@ public class NumberAnalyzed implements INumberAnalyzed {
 					Long.parseLong(st.nextToken(), 36), Long.parseLong(st.nextToken(), 36), Long.parseLong(
 							st.nextToken(), 36), Long.parseLong(st.nextToken(), 36));
 		} catch (Exception e) {
-			e.printStackTrace();
+			Logme.error(e);
 			Log.info("Error reading " + value);
 			return null;
 		}
