@@ -37,9 +37,8 @@ package net.sourceforge.plantuml.board;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
 
-import net.sourceforge.plantuml.ISkinSimple;
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.command.Command;
 import net.sourceforge.plantuml.command.CommonCommands;
 import net.sourceforge.plantuml.command.PSystemCommandFactory;
@@ -69,8 +68,8 @@ public class BoardDiagramFactory extends PSystemCommandFactory {
 	}
 
 	@Override
-	public BoardDiagram createEmptyDiagram(ThemeStyle style, UmlSource source, ISkinSimple skinParam) {
-		return new BoardDiagram(style, source);
+	public BoardDiagram createEmptyDiagram(UmlSource source, Map<String, String> skinParam) {
+		return new BoardDiagram(source);
 	}
 
 }
