@@ -131,6 +131,12 @@ public class CommandHideShowByGender extends SingleLineCommand2<UmlDiagram> {
 			gender = EntityGenderUtils.byEntityType(LeafType.ABSTRACT_CLASS);
 		} else if (arg1.equalsIgnoreCase("annotation")) {
 			gender = EntityGenderUtils.byEntityType(LeafType.ANNOTATION);
+		} else if (arg1.equalsIgnoreCase("protocol")) {
+			gender = EntityGenderUtils.byEntityType(LeafType.PROTOCOL);
+		} else if (arg1.equalsIgnoreCase("struct")) {
+			gender = EntityGenderUtils.byEntityType(LeafType.STRUCT);
+		} else if (arg1.equalsIgnoreCase("exception")) {
+			gender = EntityGenderUtils.byEntityType(LeafType.EXCEPTION);
 		} else if (arg1.startsWith("<<")) {
 			gender = EntityGenderUtils.byStereotype(arg1);
 		} else {
@@ -167,6 +173,8 @@ public class CommandHideShowByGender extends SingleLineCommand2<UmlDiagram> {
 			gender = EntityGenderUtils.byEntityType(LeafType.PROTOCOL);
 		} else if (arg1.equalsIgnoreCase("struct")) {
 			gender = EntityGenderUtils.byEntityType(LeafType.STRUCT);
+		} else if (arg1.equalsIgnoreCase("exception")) {
+			gender = EntityGenderUtils.byEntityType(LeafType.EXCEPTION);
 		} else if (arg1.startsWith("<<")) {
 			gender = EntityGenderUtils.byStereotype(arg1);
 		} else {
