@@ -111,7 +111,7 @@ public class CommandNamespace extends SingleLineCommand2<ClassDiagram> {
 		final String color = arg.get("COLOR", 0);
 		if (color != null) {
 			p.setSpecificColorTOBEREMOVED(ColorType.BACK,
-					diagram.getSkinParam().getIHtmlColorSet().getColor(diagram.getSkinParam().getThemeStyle(), color));
+					diagram.getSkinParam().getIHtmlColorSet().getColor(color));
 		}
 		return CommandExecutionResult.ok();
 	}
