@@ -60,17 +60,17 @@ public class CommandCreoleLatex implements Command {
 
 	public int matchingSize(String line) {
 		final Matcher2 m = pattern.matcher(line);
-		if (m.find() == false) {
+		if (m.find() == false)
 			return 0;
-		}
+
 		return m.group(1).length();
 	}
 
 	public String executeAndGetRemaining(String line, StripeSimple stripe) {
 		final Matcher2 m = pattern.matcher(line);
-		if (m.find() == false) {
+		if (m.find() == false)
 			throw new IllegalStateException();
-		}
+
 		final String latex = m.group(2);
 		stripe.addMath(ScientificEquationSafe.fromLatex(latex));
 		return line.substring(m.group(1).length());
