@@ -44,21 +44,18 @@ import net.sourceforge.plantuml.OptionFlags;
 import net.sourceforge.plantuml.Removeable;
 import net.sourceforge.plantuml.UmlDiagramType;
 import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
-import net.sourceforge.plantuml.command.Position;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.cucadiagram.entity.EntityImpl;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.graphic.USymbolInterface;
-import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.skin.VisibilityModifier;
 import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.svek.Bibliotekon;
 import net.sourceforge.plantuml.ugraphic.UComment;
 import net.sourceforge.plantuml.ugraphic.UFont;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.utils.UniqueSequence;
 
 public class Link extends WithLinkType implements Hideable, Removeable {
 
@@ -72,24 +69,15 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	private String port1;
 	private String port2;
 
-	final private Display label;
+	private final LinkArg linkArg;
 
-	private int length;
-	final private String qualifier1;
-	final private String qualifier2;
-	final private String uid = "LNK" + UniqueSequence.getValue();
+	final private String uid;
 
-	private Display note;
-	private Position notePosition;
-	private Colors noteColors;
-	private NoteLinkStrategy noteLinkStrategy;
+	private CucaNote note;
 
 	private boolean invis = false;
 	private double weight = 1.0;
 
-	private final String labeldistance;
-	private final String labelangle;
-
 	private boolean constraint = true;
 	private boolean inverted = false;
 	private LinkArrow linkArrow = LinkArrow.NONE_OR_SEVERAL;
@@ -97,7 +85,6 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	private boolean opale;
 	private boolean horizontalSolitary;
 	private String sametail;
-	private VisibilityModifier visibilityModifier;
 	private final StyleBuilder styleBuilder;
 	private Stereotype stereotype;
 
@@ -121,56 +108,35 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 		return new UComment("link " + getEntity1().getCodeGetName() + " to " + getEntity2().getCodeGetName());
 	}
 
-	public Link(StyleBuilder styleBuilder, IEntity cl1, IEntity cl2, LinkType type, Display label, int length) {
-		this(styleBuilder, cl1, cl2, type, label, length, null, null, null, null, null);
-	}
-
-	public Link(StyleBuilder styleBuilder, IEntity cl1, IEntity cl2, LinkType type, Display label, int length,
-			String qualifier1, String qualifier2, String labeldistance, String labelangle) {
-		this(styleBuilder, cl1, cl2, type, label, length, qualifier1, qualifier2, labeldistance, labelangle, null);
-	}
-
-	public Link(StyleBuilder styleBuilder, IEntity cl1, IEntity cl2, LinkType type, Display label, int length,
-			String qualifier1, String qualifier2, String labeldistance, String labelangle, HColor specificColor) {
-		if (length < 1)
+	public Link(StyleBuilder styleBuilder, IEntity cl1, IEntity cl2, LinkType type, LinkArg linkArg) {
+		if (linkArg.getLength() < 1)
 			throw new IllegalArgumentException();
 
 		this.styleBuilder = styleBuilder;
 		this.cl1 = Objects.requireNonNull(cl1);
 		this.cl2 = Objects.requireNonNull(cl2);
+
 		this.type = type;
-		if (Display.isNull(label)) {
-			this.label = Display.NULL;
-		} else {
-			this.label = label.manageGuillemet();
-			if (VisibilityModifier.isVisibilityCharacter(label.get(0)))
-				visibilityModifier = VisibilityModifier.getVisibilityModifier(label.get(0), false);
+		final CucaDiagram diagram = ((EntityImpl) cl1).getDiagram();
+		this.uid = "LNK" + diagram.getUniqueSequence();
 
+		this.linkArg = linkArg;
+
+		if (diagram.getPragma().useKermor()) {
+			if (cl1.getEntityPosition().isNormal() == false ^ cl2.getEntityPosition().isNormal() == false)
+				setConstraint(false);
 		}
-		this.length = length;
-		this.qualifier1 = qualifier1;
-		this.qualifier2 = qualifier2;
-		this.labeldistance = labeldistance;
-		this.labelangle = labelangle;
-		this.setSpecificColor(specificColor);
-		if (qualifier1 != null)
-			((ILeaf) cl1).setNearDecoration(true);
-
-		if (qualifier2 != null)
-			((ILeaf) cl2).setNearDecoration(true);
-
 	}
 
 	public Link getInv() {
-		final Link result = new Link(styleBuilder, cl2, cl1, getType().getInversed(), label, length, qualifier2,
-				qualifier1, labeldistance, labelangle, getSpecificColor());
+		final Link result = new Link(styleBuilder, cl2, cl1, getType().getInversed(), linkArg.getInv());
 		result.inverted = !this.inverted;
 		result.port1 = this.port2;
 		result.port2 = this.port1;
 		result.url = this.url;
 		result.linkConstraint = this.linkConstraint;
 		result.stereotype = stereotype;
-		result.visibilityModifier = visibilityModifier;
+		result.linkArg.setVisibilityModifier(this.linkArg.getVisibilityModifier());
 		return result;
 	}
 
@@ -181,12 +147,12 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 
 	public String getLabeldistance() {
 		// Default in dot 1.0
-		return labeldistance;
+		return getLinkArg().getLabeldistance();
 	}
 
 	public String getLabelangle() {
 		// Default in dot -25
-		return labelangle;
+		return getLinkArg().getLabelangle();
 	}
 
 	public String getUid() {
@@ -216,7 +182,7 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 
 	@Override
 	public String toString() {
-		return super.toString() + " {" + length + "} " + cl1 + "-->" + cl2;
+		return super.toString() + " {" + linkArg.getLength() + "} " + cl1 + "-->" + cl2;
 	}
 
 	public IEntity getEntity1() {
@@ -228,11 +194,17 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public EntityPort getEntityPort1(Bibliotekon bibliotekon) {
-		return new EntityPort(bibliotekon.getNodeUid((ILeaf) cl1), port1);
+		return getEntityPort((ILeaf) cl1, port1, bibliotekon);
 	}
 
 	public EntityPort getEntityPort2(Bibliotekon bibliotekon) {
-		return new EntityPort(bibliotekon.getNodeUid((ILeaf) cl2), port2);
+		return getEntityPort((ILeaf) cl2, port2, bibliotekon);
+	}
+
+	private EntityPort getEntityPort(ILeaf leaf, String port, Bibliotekon bibliotekon) {
+		if (leaf.getEntityPosition().usePortP())
+			return EntityPort.forPort(bibliotekon.getNodeUid(leaf));
+		return EntityPort.create(bibliotekon.getNodeUid(leaf), port);
 	}
 
 	@Override
@@ -295,23 +267,23 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public Display getLabel() {
-		return label;
+		return getLinkArg().getLabel();
 	}
 
 	public int getLength() {
-		return length;
+		return getLinkArg().getLength();
 	}
 
 	public final void setLength(int length) {
-		this.length = length;
+		this.getLinkArg().setLength(length);
 	}
 
 	public String getQualifier1() {
-		return qualifier1;
+		return getLinkArg().getQualifier1();
 	}
 
 	public String getQualifier2() {
-		return qualifier2;
+		return getLinkArg().getQualifier2();
 	}
 
 	public final double getWeight() {
@@ -322,34 +294,17 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 		this.weight = weight;
 	}
 
-	public final Display getNote() {
+	public final CucaNote getNote() {
 		return note;
 	}
 
-	public final NoteLinkStrategy getNoteLinkStrategy() {
-		return noteLinkStrategy;
-	}
-
-	public final Colors getNoteColors() {
-		return noteColors;
-	}
-
-	public final Position getNotePosition() {
-		return notePosition;
-	}
-
-	public final void addNote(Display note, Position position, Colors colors) {
+	public final void addNote(CucaNote note) {
 		this.note = note;
-		this.notePosition = position;
-		this.noteColors = colors;
-		this.noteLinkStrategy = NoteLinkStrategy.NORMAL;
 	}
 
 	public final void addNoteFrom(Link other, NoteLinkStrategy strategy) {
-		this.note = other.note;
-		this.notePosition = other.notePosition;
-		this.noteColors = other.noteColors;
-		this.noteLinkStrategy = strategy;
+		if (other.note != null)
+			this.note = other.note.withStrategy(strategy);
 	}
 
 	public boolean isAutoLinkOfAGroup() {
@@ -389,24 +344,24 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 		throw new IllegalArgumentException();
 	}
 
-	public double getMarginDecors1(StringBounder stringBounder, UFont fontQualif, ISkinSimple spriteContainer) {
-		final double q = getQualifierMargin(stringBounder, fontQualif, qualifier1, spriteContainer);
-		final LinkDecor decor = getType().getDecor1();
-		return decor.getMargin() + q;
-	}
-
-	public double getMarginDecors2(StringBounder stringBounder, UFont fontQualif, ISkinSimple spriteContainer) {
-		final double q = getQualifierMargin(stringBounder, fontQualif, qualifier2, spriteContainer);
-		final LinkDecor decor = getType().getDecor2();
-		return decor.getMargin() + q;
-	}
+//	public double getMarginDecors1(StringBounder stringBounder, UFont fontQualif, ISkinSimple spriteContainer) {
+//		final double q = getQualifierMargin(stringBounder, fontQualif, linkArg.getQualifier1(), spriteContainer);
+//		final LinkDecor decor = getType().getDecor1();
+//		return decor.getMargin() + q;
+//	}
+//
+//	public double getMarginDecors2(StringBounder stringBounder, UFont fontQualif, ISkinSimple spriteContainer) {
+//		final double q = getQualifierMargin(stringBounder, fontQualif, linkArg.getQualifier2(), spriteContainer);
+//		final LinkDecor decor = getType().getDecor2();
+//		return decor.getMargin() + q;
+//	}
 
 	private double getQualifierMargin(StringBounder stringBounder, UFont fontQualif, String qualif,
 			ISkinSimple spriteContainer) {
 		if (qualif != null) {
 			final TextBlock b = Display.create(qualif).create(FontConfiguration.blackBlueTrue(fontQualif),
 					HorizontalAlignment.LEFT, spriteContainer);
-			final Dimension2D dim = b.calculateDimension(stringBounder);
+			final XDimension2D dim = b.calculateDimension(stringBounder);
 			return Math.max(dim.getWidth(), dim.getHeight());
 		}
 		return 0;
@@ -448,15 +403,14 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public boolean hasEntryPoint() {
-		return (getEntity1().isGroup() == false && ((ILeaf) getEntity1()).getEntityPosition() != EntityPosition.NORMAL)
-				|| (getEntity2().isGroup() == false
-						&& ((ILeaf) getEntity2()).getEntityPosition() != EntityPosition.NORMAL);
+		return (getEntity1().isGroup() == false && getEntity1().getEntityPosition() != EntityPosition.NORMAL)
+				|| (getEntity2().isGroup() == false && getEntity2().getEntityPosition() != EntityPosition.NORMAL);
 	}
 
 	public boolean hasTwoEntryPointsSameContainer() {
 		return getEntity1().isGroup() == false && getEntity2().isGroup() == false
-				&& ((ILeaf) getEntity1()).getEntityPosition() != EntityPosition.NORMAL
-				&& ((ILeaf) getEntity2()).getEntityPosition() != EntityPosition.NORMAL
+				&& getEntity1().getEntityPosition() != EntityPosition.NORMAL
+				&& getEntity2().getEntityPosition() != EntityPosition.NORMAL
 				&& getEntity1().getParentContainer() == getEntity2().getParentContainer();
 	}
 
@@ -507,7 +461,7 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public boolean hasUrl() {
-		if (Display.isNull(label) == false && label.hasUrl())
+		if (Display.isNull(linkArg.getLabel()) == false && linkArg.getLabel().hasUrl())
 			return true;
 
 		return getUrl() != null;
@@ -532,10 +486,6 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 
 	}
 
-	public final VisibilityModifier getVisibilityModifier() {
-		return visibilityModifier;
-	}
-
 	private UmlDiagramType umlType;
 
 	public void setUmlDiagramType(UmlDiagramType type) {
@@ -577,4 +527,12 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 		return stereotype;
 	}
 
+	public final LinkArg getLinkArg() {
+		return linkArg;
+	}
+
+	public final VisibilityModifier getVisibilityModifier() {
+		return getLinkArg().getVisibilityModifier();
+	}
+
 }
