@@ -209,7 +209,7 @@ public class CommandCreateElementFull extends SingleLineCommand2<DescriptionDiag
 			type = LeafType.PORTOUT;
 			usymbol = null;
 		} else if (symbol.equalsIgnoreCase("port")) {
-			type = LeafType.PORT;
+			type = LeafType.PORTIN;
 			usymbol = null;
 		} else if (symbol.equalsIgnoreCase("usecase")) {
 			type = LeafType.USECASE;
@@ -263,12 +263,11 @@ public class CommandCreateElementFull extends SingleLineCommand2<DescriptionDiag
 			entity.addUrl(url);
 		}
 
-		Colors colors = color().getColor(diagram.getSkinParam().getThemeStyle(), arg,
-				diagram.getSkinParam().getIHtmlColorSet());
+		Colors colors = color().getColor(arg, diagram.getSkinParam().getIHtmlColorSet());
 		final String s = arg.get("LINECOLOR", 1);
 
 		final HColor lineColor = s == null ? null
-				: diagram.getSkinParam().getIHtmlColorSet().getColor(diagram.getSkinParam().getThemeStyle(), s);
+				: diagram.getSkinParam().getIHtmlColorSet().getColor(s);
 		if (lineColor != null) {
 			colors = colors.add(ColorType.LINE, lineColor);
 		}
