@@ -43,7 +43,7 @@ public class NTetris<S extends Staged> {
 
 	private final Map<S, Integer> all = new LinkedHashMap<>();
 	private final BooleanGrid grid = new BooleanGrid();
-	
+
 	@Override
 	public String toString() {
 		return all.toString();
@@ -58,9 +58,9 @@ public class NTetris<S extends Staged> {
 				return;
 			}
 			x++;
-			if (x > 100) {
+			if (x > 100)
 				throw new IllegalStateException();
-			}
+
 		}
 	}
 
@@ -70,9 +70,9 @@ public class NTetris<S extends Staged> {
 
 	public int getNWidth() {
 		int max = 0;
-		for (Entry<S, Integer> ent : all.entrySet()) {
+		for (Entry<S, Integer> ent : all.entrySet())
 			max = Math.max(max, ent.getValue() + ent.getKey().getNWidth());
-		}
+
 		return max;
 	}
 
