@@ -35,48 +35,49 @@
  */
 package net.sourceforge.plantuml.posimo;
 
-import java.awt.geom.CubicCurve2D;
-import java.awt.geom.Line2D;
-import java.awt.geom.Point2D;
-import java.awt.geom.Rectangle2D;
+import net.sourceforge.plantuml.awt.geom.XCubicCurve2D;
+import net.sourceforge.plantuml.awt.geom.XLine2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
+import net.sourceforge.plantuml.awt.geom.XRectangle2D;
 
 public class RacorderOrthogonal extends RacorderAbstract implements Racorder {
 
-	public DotPath getRacordIn(Rectangle2D rect, Line2D tangeante) {
+	@Override
+	public DotPath getRacordIn(XRectangle2D rect, XLine2D tangeante) {
 
-		final Point2D in = tangeante.getP1();
+		final XPoint2D in = tangeante.getP1();
 
 		final DotPath result = new DotPath();
-		Point2D inter = null;
+		XPoint2D inter = null;
 
 		if (in.getX() > rect.getMinX() && in.getX() < rect.getMaxX()) {
-			if (in.getY() < rect.getMinY()) {
-				inter = new Point2D.Double(in.getX(), rect.getMinY());
-			} else if (in.getY() > rect.getMaxY()) {
-				inter = new Point2D.Double(in.getX(), rect.getMaxY());
-			} else {
+			if (in.getY() < rect.getMinY())
+				inter = new XPoint2D(in.getX(), rect.getMinY());
+			else if (in.getY() > rect.getMaxY())
+				inter = new XPoint2D(in.getX(), rect.getMaxY());
+			else
 				throw new IllegalArgumentException();
-			}
+
 		} else if (in.getY() > rect.getMinY() && in.getY() < rect.getMaxY()) {
-			if (in.getX() < rect.getMinX()) {
-				inter = new Point2D.Double(rect.getMinX(), in.getY());
-			} else if (in.getX() > rect.getMaxX()) {
-				inter = new Point2D.Double(rect.getMaxX(), in.getY());
-			} else {
+			if (in.getX() < rect.getMinX())
+				inter = new XPoint2D(rect.getMinX(), in.getY());
+			else if (in.getX() > rect.getMaxX())
+				inter = new XPoint2D(rect.getMaxX(), in.getY());
+			else
 				throw new IllegalArgumentException();
-			}
+
 		} else {
-			final Point2D p1 = new Point2D.Double(rect.getMinX(), rect.getMinY());
-			final Point2D p2 = new Point2D.Double(rect.getMaxX(), rect.getMinY());
-			final Point2D p3 = new Point2D.Double(rect.getMaxX(), rect.getMaxY());
-			final Point2D p4 = new Point2D.Double(rect.getMinX(), rect.getMaxY());
+			final XPoint2D p1 = new XPoint2D(rect.getMinX(), rect.getMinY());
+			final XPoint2D p2 = new XPoint2D(rect.getMaxX(), rect.getMinY());
+			final XPoint2D p3 = new XPoint2D(rect.getMaxX(), rect.getMaxY());
+			final XPoint2D p4 = new XPoint2D(rect.getMinX(), rect.getMaxY());
 
 			inter = LineRectIntersection.getCloser(tangeante.getP1(), p1, p2, p3, p4);
 
 		}
 
-		final CubicCurve2D.Double curv = new CubicCurve2D.Double(tangeante.getX1(), tangeante.getY1(),
-				tangeante.getX1(), tangeante.getY1(), inter.getX(), inter.getY(), inter.getX(), inter.getY());
+		final XCubicCurve2D curv = new XCubicCurve2D(tangeante.getX1(), tangeante.getY1(), tangeante.getX1(),
+				tangeante.getY1(), inter.getX(), inter.getY(), inter.getX(), inter.getY());
 		return result.addAfter(curv);
 	}
 
