@@ -43,6 +43,7 @@ import java.nio.charset.Charset;
 
 import net.sourceforge.plantuml.Log;
 import net.sourceforge.plantuml.StringLocated;
+import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.security.SURL;
 import net.sourceforge.plantuml.utils.StartUtils;
 
@@ -86,7 +87,7 @@ public class StartDiagramExtractReader implements ReadLine {
 				}
 			}
 		} catch (IOException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			Log.error("Error " + e);
 		}
 		finished = true;
