@@ -109,7 +109,7 @@ public class GanttArrow implements UDrawable {
 	}
 
 	public void drawU(UGraphic ug) {
-		ug = style.applyStrokeAndLineColor(ug, colorSet, styleBuilder.getSkinParam().getThemeStyle());
+		ug = style.applyStrokeAndLineColor(ug, colorSet);
 
 		final TaskDraw start = getSource();
 		final TaskDraw end = getDestination();
@@ -153,7 +153,7 @@ public class GanttArrow implements UDrawable {
 		}
 
 		ug = ug.apply(new UStroke(1.5)).apply(
-				style.value(PName.LineColor).asColor(styleBuilder.getSkinParam().getThemeStyle(), colorSet).bg());
+				style.value(PName.LineColor).asColor(colorSet).bg());
 		ug.apply(new UTranslate(x2, y2)).draw(Arrows.asTo(atEnd));
 
 	}
